/*
 * gsampler-client-database.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 * 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_CLIENT_DATABASE_H_
#define _GSAMPLER_CLIENT_DATABASE_H_

#include "gsampler-client.h"

#define GSAMPLER_TYPE_DB_INST_INFO (gsampler_db_inst_info_get_type ())
typedef struct _GsamplerDbInstInfo GsamplerDbInstInfo;
struct _GsamplerDbInstInfo {
	gchar *name;
	gchar *db_path;
	gchar* file;
	gint number;
	gchar* format_family;
	gchar* format_version;
	float size;
	gchar* type;
	gchar* created;
	gchar* modified;
	gchar* desc;
	gchar* product;
	gchar* artists;
	gchar* keywords;
};

#define GSAMPLER_TYPE_DB_JOB_INFO (gsampler_db_job_info_get_type ())
typedef struct _GsamplerDbJobInfo GsamplerDbJobInfo;
struct _GsamplerDbJobInfo {
	gdouble total;
	gdouble scanned;
	gchar* scanning;
	gdouble status;
};

GType gsampler_db_inst_info_get_type (void) G_GNUC_CONST;
GsamplerDbInstInfo* gsampler_db_inst_info_dup (const GsamplerDbInstInfo* self);
void gsampler_db_inst_info_free (GsamplerDbInstInfo* self);
void gsampler_db_inst_info_copy (const GsamplerDbInstInfo* self, GsamplerDbInstInfo* dest);
void gsampler_db_inst_info_destroy (GsamplerDbInstInfo* self);

GType gsampler_db_job_info_get_type (void) G_GNUC_CONST;
GsamplerDbJobInfo* gsampler_db_job_info_dup (const GsamplerDbJobInfo* self);
void gsampler_db_job_info_free (GsamplerDbJobInfo* self);
void gsampler_db_job_info_copy (const GsamplerDbJobInfo* self, GsamplerDbJobInfo* dest);
void gsampler_db_job_info_destroy (GsamplerDbJobInfo* self);

gchar** 			gsampler_client_db_list_dir (GsamplerClient* self, const gchar* path);
gchar** 			gsampler_client_db_list_instrument (GsamplerClient* self, const gchar* path);
GsamplerDbInstInfo*	gsampler_client_db_get_instrument_info (GsamplerClient* self, const gchar* path);
gboolean 			gsampler_client_db_format_instruments (GsamplerClient* self);
gint 				gsampler_client_db_add_instrument (GsamplerClient* self, const gchar* db_base, 
		                                        	   const gchar* path, gboolean recur, gboolean flat, 
		                                        	   gboolean as_dir, gint index);
GsamplerDbJobInfo*	gsampler_client_db_get_job_info (GsamplerClient* self, gint job);
gboolean			gsampler_client_db_move_dir (GsamplerClient* self,
			                                     const gchar* dir, const gchar* dst);
gboolean			gsampler_client_db_copy_dir (GsamplerClient* self,
			                                     const gchar* dir, const gchar* dst);
gboolean			gsampler_client_db_remove_dir (GsamplerClient* self, const gchar* dir);
gboolean			gsampler_client_db_rename_dir (GsamplerClient* self,
			                                       const gchar* dir, const gchar* name);
gchar**				gsampler_client_db_find_instrument(GsamplerClient* self, 
				                                       const gchar* dir, const gchar* name);
gchar**				gsampler_client_db_check_lost_inst_files (GsamplerClient* self);
gboolean			gsampler_client_db_move_instrument (GsamplerClient* self,
			                                            const gchar* instr, const gchar* dst);
gboolean			gsampler_client_db_copy_instrument (GsamplerClient* self,
			                                            const gchar* instr, const gchar* dst);
gboolean			gsampler_client_db_remove_instrument (GsamplerClient* self, const gchar* instr);
gboolean			gsampler_client_db_rename_instrument (GsamplerClient* self,
			                                              const gchar* instr, const gchar* name);
gboolean			gsampler_client_db_set_instrument_desc (GsamplerClient *self, 
			                                                const gchar* instr, const gchar* desc);

#endif /* _GSAMPLER_CLIENT_DATABASE_H_ */